from _typeshed import Incomplete

from braintree.configuration import Configuration as Configuration

class WebhookTesting:
    @staticmethod
    def sample_notification(kind, id, source_merchant_id: Incomplete | None = None): ...
