from _typeshed import Incomplete

from braintree.attribute_getter import AttributeGetter as AttributeGetter

class RiskData(AttributeGetter):
    def __init__(self, attributes: Incomplete) -> None: ...
